==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fshared_calendars-0.5.7-1.2.3.tar.gz: calendar/calendar_check.php <==
<?php

 include_once ("calendar_data.php");
 include_once ("functions.php");
 include_once ("shared_functions.php");
 chdir("..");
 include_once ("../src/validate.php");
 include_once('../functions/strings.php');
 include_once('../config/config.php');
 include_once('../functions/page_header.php');
 include_once('../src/load_prefs.php');


global $username, $data_dir, $color, $cal;
displayPageHeader($color, "None");

$shared_list = read_calendar_list($data_dir, 'shared');
$public_list = read_calendar_list($data_dir, 'public');

$ccode = get_user_code($data_dir, $username);
if ($ccode == '') {
    $cal_num = count($shared_list);
    $ccode = str_repeat("0", $cal_num);
}

print "<br><br><table width=\"60%\" bgcolor=\"$color[9]\"align=center>\n";
print "<tr><td align=center><b>Available calendars</b></td></tr><tr><td>\n";
print "<table width=\"100%\" align=center bgcolor=\"$color[4]\">\n";
$count = count($public_list); 
for ($x=0;$x<$count;$x++) {
    $url_calendar=urlencode($public_list[$x]);
    print "<tr><td align=center nowrap><a href=\"calendar.php?cal=$url_calendar\">$public_list[$x]</a></td></tr>";
}
$code = preg_split('//', $ccode, -1, PREG_SPLIT_NO_EMPTY);
for ($x=0;$x<count($shared_list);$x++) {
    $url_calendar = urlencode($shared_list[$x]);
	switch ($code[$x]) {
		case 0:
		break;
		case 1:
		case 2:
		print "<tr><td align=center nowrap><a href=\"calendar.php?cal=$url_calendar\">$shared_list[$x]</a></td></tr>";
		break;
		default:
		break;
	}
}
print "<tr><td nowrap align=center><a href=\"calendar.php?cal=Personal\">Personal</a></big></td></tr>";
print "</table></td></tr></table>\n";
?>

==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fshared_calendars-1.0.1-1.4.0.tar.gz: calendar/calendar_check.php <==
<?php

define('SM_PATH','../../');

/* Calender plugin required files. */
require_once(SM_PATH . 'plugins/calendar/calendar_data.php');
require_once(SM_PATH . 'plugins/calendar/functions.php');
require_once(SM_PATH . 'plugins/calendar/shared_functions.php');

/* SquirrelMail required files. */
require_once(SM_PATH . 'include/validate.php');
require_once(SM_PATH . 'functions/strings.php');
require_once(SM_PATH . 'functions/date.php');
require_once(SM_PATH . 'config/config.php');
require_once(SM_PATH . 'functions/page_header.php');
require_once(SM_PATH . 'include/load_prefs.php');
require_once(SM_PATH . 'functions/html.php');

global $username, $data_dir, $color, $cal;
displayPageHeader($color, "None");

$shared_list = read_calendar_list($data_dir, 'shared');
$public_list = read_calendar_list($data_dir, 'public');

$ccode = get_user_code($data_dir, $username);
if ($ccode == '') {
    $cal_num = count($shared_list);
    $ccode = str_repeat("0", $cal_num);
}

print "<br><br><table width=\"60%\" bgcolor=\"$color[9]\"align=center>\n";
print "<tr><td align=center><b>Available calendars</b></td></tr><tr><td>\n";
print "<table width=\"100%\" align=center bgcolor=\"$color[4]\">\n";
$count = count($public_list); 
for ($x=0;$x<$count;$x++) {
    $url_calendar=urlencode($public_list[$x]);
    print "<tr><td align=center nowrap><a href=\"calendar.php?cal=$url_calendar\">$public_list[$x]</a></td></tr>";
}
$code = preg_split('//', $ccode, -1, PREG_SPLIT_NO_EMPTY);
for ($x=0;$x<count($shared_list);$x++) {
    $url_calendar = urlencode($shared_list[$x]);
	switch ($code[$x]) {
		case 0:
		break;
		case 1:
		case 2:
		print "<tr><td align=center nowrap><a href=\"calendar.php?cal=$url_calendar\">$shared_list[$x]</a></td></tr>";
		break;
		default:
		break;
	}
}
print "<tr><td nowrap align=center><a href=\"calendar.php?cal=Personal\">Personal</a></big></td></tr>";
print "</table></td></tr></table>\n";
?>
